'use client'
import React, {useEffect, useState} from "react";
import {Button} from "@/components/ui/button";
import Link from "next/link";
import {AccountService} from "@/services/account.service";
import {IUserDataProfile} from "@/types/userdata.type";
import {TriangleAlert} from "lucide-react";
import {Profile} from "@/components/profile";

export default function ProfilePage() {
	const token = localStorage.getItem('token') || false
	if (!token) {
		return (
			<main className="flex flex-col justify-evenly items-center antialiased h-full w-full gap-2">
				<h1 className={'md:text-xl text-center'}>You should be logged to see the page.</h1>
				<div className={'flex flex-row justify-center gap-2 md:scale-125'}>
					<Button size="default" asChild><Link href={'/account/login'}>Login</Link></Button>
					<Button size="default" variant="outline" asChild><Link href={'/account/register'}>Register</Link></Button>
				</div>
			</main>
		);
	}

	const [userData, setUserData] = useState<IUserDataProfile>();
	const [httpError, setHttpError] = useState<string>()
	useEffect(() => {
      const fetchData = async () => {
          try {
              const response = await AccountService.getUserData();
              if (typeof response === 'string') {
								setHttpError(response)
								return
							}
							setUserData(response);
          } catch (error) {
              console.error(error);
          }
      };
      fetchData();
  }, []);

	if (httpError) {
		return (
			<main className="flex flex-col justify-evenly items-center antialiased h-full w-full gap-2">
				<div className={'flex flex-col md:flex-row justify-center items-center gap-2 md:scale-125 text-orange-500 font-bold'}>
					<TriangleAlert className={
						'md:scale-150'
					} />
					<h1 className={'md:text-xl text-center'}>{`${httpError}`}</h1>
				</div>
			</main>
		);
	}

	if (userData?.email) {
		return (
			<main className="flex flex-col justify-evenly items-center antialiased h-full w-full">
				<Profile userData={userData}/>
			</main>
		);
	}
	return (
    <main className="flex flex-col justify-evenly items-center antialiased h-full w-full gap-2">
      <h1 className={'md:text-xl text-center'}>Loading...</h1>
    </main>
  );
}